==> seller-config-client-api-4.0.34-20220402.063117-4-sources.jar: com/xforceplus/seller/config/client/parse/bean/SysInfoRuleDTO.java <==
package com.xforceplus.seller.config.client.parse.bean;/**
 * Created by admin on 2018/10/16.
 */

import com.xforceplus.seller.config.client.parse.BaseRuleBean;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;

import java.math.BigDecimal;
import java.util.List;

/**
 * @Author
 * @Description 返回给微服务。
 * @Date
 * @return
 **/
@ApiModel
@Getter
@Setter
public class SysInfoRuleDTO extends BaseRuleBean {
    @ApiModelProperty("上传是否校验红字信息")
    private Boolean checkRedBillFalg; //是否校验红字信息
    @ApiModelProperty("是否校验原蓝字信息")
    private Boolean checkRedBillOriginInvoiceFalg;  //是否校验原蓝字信息
    @ApiModelProperty("AR业务单是否查查验购方信息")
    private Boolean checkARBillPurchaseInfoFalg;//AR业务单是否查查验购方信息
    @ApiModelProperty("AP业务单是否查验销方信息")
    private Boolean checkAPBillSellerInfoFalg;//AP业务单是否查验销方信息
    @ApiModelProperty("是否自动补全正确的税编")
    private Boolean autoUpdateTaxCodeFlag; //是否自动补全正确的税编
    @ApiModelProperty("普通发票是否需要简称")
    private Boolean comInvoiceNeedShortNameFlag;//普通发票是否需要简称
    @ApiModelProperty("拆票规则 成品油是否可以混开")
    private Boolean reffiendOilMixOpenFlag;//拆票规则 成品油是否可以混开
    @ApiModelProperty("是否通过转换代码校验税率")
    private Boolean checkTaxRateByConvertCodeFlag;//是否通过转换代码校验税率
    @ApiModelProperty("预付卡金额支付是否自动补一分钱商品")
    private Boolean prePayCardAutoOneGoodFlag;//预付卡金额支付是否自动补一分钱商品
    @ApiModelProperty("普票是否允许相同的购销方")
    private Boolean comInvoiceAllowSameSellerOrPurcherFlg;//普票是否允许相同的购销方
    @ApiModelProperty("纸票开具后是否自动发送pdf")
    private Boolean paperInvoiceMakeAutosendPdfFlag;//纸票开具后是否自动发送pdf
    @ApiModelProperty("发票开具是否提示打印业务单封面")
    private Boolean invoiceMakeRemindPrintBillBackGroundFlag;//发票开具是否提示打印业务单封面
    @ApiModelProperty("是否自动分摊预付卡")
    private Boolean autoSplitPreCardFlag; //是否自动分摊预付卡
    @ApiModelProperty("专票是否允许相同的购销方")
    private Boolean speInvoiceAllowSameSellerOrPurcharseFlag;//专票是否允许相同的购销方
    @ApiModelProperty("发票锁控制")
    private Boolean invoiceLock;//发票锁控制
    @ApiModelProperty("电票是否需要简称")
    private Boolean elecInvoiceNeedShortNameFlag;//电票是否需要简称
    @ApiModelProperty("电票开具后是否自动发送邮件")
    private Boolean elecInvoiceMakeAutoSendEmailFlag;//电票开具后是否自动发送邮件
    @ApiModelProperty("专票是否需要简称")
    private Boolean speInvoiceNeedShortNameFlag;//专票是否需要简称
    @ApiModelProperty("是否自动拆分折扣")
    private Boolean autoSplitDiscountFlag;//是否自动拆分折扣
    @ApiModelProperty("是否允许上传正负明细混合上传")
    private Boolean uploadNagertiveMixBillFlag;//是否允许上传正负明细混合上传
    @ApiModelProperty("是否发送协同产品线")
    private Boolean sendToAntFlag;//是否允许上传正负明细混合上传

    @ApiModelProperty("单据生成预制发票是否跳过弹窗(目的是提供修改机会)")
    private Integer bill2PreviewInvoiceSkipFlag;

    @ApiModelProperty("是否发送邮件")
    private String sendMailFlag;

    @ApiModelProperty("AR单据上传是否自动确认 默认是true 保持原有逻辑 false 进入待确认状态")
    private Boolean uploadBillAutoConfirm;

    @ApiModelProperty("业务单容差--在容差范围类允许修改金额")
    private BigDecimal billTolerance;

    @ApiModelProperty("红字信息与预制发票比对容差--在容差范围类允许开票")
    private BigDecimal redNoCompareTolerance;

    @ApiModelProperty("业务单折扣率")
    private String bizBillDiscountRate = "1";

    @ApiModelProperty("发票匹配容差")
    private BigDecimal invoiceMatchTolerance;

    @ApiModelProperty("是否配置对账服务")
    private Boolean reconFlag;

    @ApiModelProperty("专纸红冲是否释放预制发票/业务单")
    private List<Integer> spePaperInoviceRedFlushReleaseFalg;//专纸红冲是否释放预制发票/业务单

    @ApiModelProperty("普纸红冲是否释放预制发票/业务单")
    private List<Integer> comPaperInvoiceRedFlushReleaseFlag;//普纸红冲是否释放预制发票/业务单

    @ApiModelProperty("电票红冲是否释放预制发票/业务单")
    private List<Integer> elecInvoiceRedFlushReleaseFalg;     //电票红冲是否释放预制发票/业务单

    @ApiModelProperty("普纸作废是否释放预制发票/业务单")
    private List<Integer> comPaperInoviceDrawftReleaseFlag; //普纸作废是否释放预制发票/业务单

    @ApiModelProperty("专纸作废是否释放预制发票/业务单")
    private List<Integer> spePaperInoviceDrawftReleaseFlag; //专纸作废是否释放预制发票/业务单

    @ApiModelProperty("修改AR业务单购方抬头同时更新客户信息")
    private String updateARBillAndCasm;

    @ApiModelProperty("修改AR业务单商品信息同时更新商品信息")
    private String updateARBillAndGoods;

    @ApiModelProperty("默认红冲原因")
    private String redInvoiceReason;
    @ApiModelProperty("cusomterNo")
    private String customerNo;
    @ApiModelProperty("顾客提交抬头时手机号必填")
    private String invoiceTitlePhoneRequired;
    @ApiModelProperty("顾客可申请的发票类型")
    private List<String> invoiceTitleApplyInvoiceType;
    @ApiModelProperty("扫码H5类型")
    private String followWechat;
    @ApiModelProperty("订单查询来源")
    private String orderSearchSource;
    @ApiModelProperty("订单查询条件")
    private String orderSearchCondition;
    @ApiModelProperty("开票等待提示语(开票申请)")
    private String salesBillApplyInvoiceHint;
    @ApiModelProperty("顾客扫码填写额外信息(扫码抬头)")
    private String invoiceTitleCustomFieldName;
    @ApiModelProperty("顾客扫码额外信息是否必填(扫码抬头)")
    private String invoiceTitleCustomFieldRequired;
    @ApiModelProperty("已开订单是否可重复开具")
    private String canRepeatInvoice;
    @ApiModelProperty("上传是否自动【开电票】")
    private List<String> uploadBillAutoMakeElectronic;
    @ApiModelProperty("自动开具开票点配置")
    private String autoMakeTerminal;
    @ApiModelProperty("固定商品明细")
    private String invoiceFixedGoodsNo;
}

==> seller-config-client-api-4.1.30-20250928.033323-2-sources.jar: com/xforceplus/seller/config/client/parse/bean/SysInfoRuleDTO.java <==
package com.xforceplus.seller.config.client.parse.bean;

import com.xforceplus.seller.config.client.parse.BaseRuleBean;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;

import java.math.BigDecimal;
import java.util.List;

/**
 * @Author
 * @Description 返回给微服务。
 * @Date
 * @return
 **/
@ApiModel
@Getter
@Setter
public class SysInfoRuleDTO extends BaseRuleBean {
    @ApiModelProperty("上传是否校验红字信息")
    private Boolean checkRedBillFalg; //是否校验红字信息
    @ApiModelProperty("是否校验原蓝字信息")
    private Boolean checkRedBillOriginInvoiceFalg;  //是否校验原蓝字信息
    @ApiModelProperty("AR业务单是否查查验购方信息")
    private Boolean checkARBillPurchaseInfoFalg;//AR业务单是否查查验购方信息
    @ApiModelProperty("AP业务单是否查验销方信息")
    private Boolean checkAPBillSellerInfoFalg;//AP业务单是否查验销方信息
    @ApiModelProperty("是否自动补全正确的税编")
    private Boolean autoUpdateTaxCodeFlag; //是否自动补全正确的税编
    @ApiModelProperty("普通发票是否需要简称")
    private Boolean comInvoiceNeedShortNameFlag;//普通发票是否需要简称
    @ApiModelProperty("拆票规则 成品油是否可以混开")
    private Boolean reffiendOilMixOpenFlag;//拆票规则 成品油是否可以混开
    @ApiModelProperty("是否通过转换代码校验税率")
    private Boolean checkTaxRateByConvertCodeFlag;//是否通过转换代码校验税率
    @ApiModelProperty("预付卡金额支付是否自动补一分钱商品")
    private Boolean prePayCardAutoOneGoodFlag;//预付卡金额支付是否自动补一分钱商品
    @ApiModelProperty("普票是否允许相同的购销方")
    private Boolean comInvoiceAllowSameSellerOrPurcherFlg;//普票是否允许相同的购销方
    @ApiModelProperty("纸票开具后是否自动发送pdf")
    private Boolean paperInvoiceMakeAutosendPdfFlag;//纸票开具后是否自动发送pdf
    @ApiModelProperty("发票开具是否提示打印业务单封面")
    private Boolean invoiceMakeRemindPrintBillBackGroundFlag;//发票开具是否提示打印业务单封面
    @ApiModelProperty("是否自动分摊预付卡")
    private Boolean autoSplitPreCardFlag; //是否自动分摊预付卡
    @ApiModelProperty("专票是否允许相同的购销方")
    private Boolean speInvoiceAllowSameSellerOrPurcharseFlag;//专票是否允许相同的购销方
    @ApiModelProperty("发票锁控制")
    private Boolean invoiceLock;//发票锁控制
    @ApiModelProperty("电票是否需要简称")
    private Boolean elecInvoiceNeedShortNameFlag;//电票是否需要简称
    @ApiModelProperty("电票开具后是否自动发送邮件")
    private Boolean elecInvoiceMakeAutoSendEmailFlag;//电票开具后是否自动发送邮件
    @ApiModelProperty("专票是否需要简称")
    private Boolean speInvoiceNeedShortNameFlag;//专票是否需要简称
    @ApiModelProperty("是否自动拆分折扣")
    private Boolean autoSplitDiscountFlag;//是否自动拆分折扣
    @ApiModelProperty("是否允许上传正负明细混合上传")
    private Boolean uploadNagertiveMixBillFlag;//是否允许上传正负明细混合上传
    @ApiModelProperty("是否发送协同产品线")
    private Boolean sendToAntFlag;//是否允许上传正负明细混合上传

    @ApiModelProperty("单据生成预制发票是否跳过弹窗(目的是提供修改机会)")
    private Integer bill2PreviewInvoiceSkipFlag;

    @ApiModelProperty("是否发送邮件")
    private String sendMailFlag;

    @ApiModelProperty("AR单据上传是否自动确认 默认是true 保持原有逻辑 false 进入待确认状态")
    private Boolean uploadBillAutoConfirm;

    @ApiModelProperty("业务单容差--在容差范围类允许修改金额")
    private BigDecimal billTolerance;

    @ApiModelProperty("红字信息与预制发票比对容差--在容差范围类允许开票")
    private BigDecimal redNoCompareTolerance;

    @ApiModelProperty("业务单折扣率")
    private String bizBillDiscountRate = "1";

    @ApiModelProperty("发票匹配容差")
    private BigDecimal invoiceMatchTolerance;

    @ApiModelProperty("是否配置对账服务")
    private Boolean reconFlag;

    @ApiModelProperty("专纸红冲是否释放预制发票/业务单")
    private List<Integer> spePaperInoviceRedFlushReleaseFalg;//专纸红冲是否释放预制发票/业务单

    @ApiModelProperty("普纸红冲是否释放预制发票/业务单")
    private List<Integer> comPaperInvoiceRedFlushReleaseFlag;//普纸红冲是否释放预制发票/业务单

    @ApiModelProperty("电票红冲是否释放预制发票/业务单")
    private List<Integer> elecInvoiceRedFlushReleaseFalg;     //电票红冲是否释放预制发票/业务单

    @ApiModelProperty("普纸作废是否释放预制发票/业务单")
    private List<Integer> comPaperInoviceDrawftReleaseFlag; //普纸作废是否释放预制发票/业务单

    @ApiModelProperty("专纸作废是否释放预制发票/业务单")
    private List<Integer> spePaperInoviceDrawftReleaseFlag; //专纸作废是否释放预制发票/业务单

    @ApiModelProperty("机动车票红冲是否释放预制发票/业务单")
    private List<Integer> vehicleInvoiceRedFlushReleaseFlag;

    @ApiModelProperty("修改AR业务单购方抬头同时更新客户信息")
    private String updateARBillAndCasm;

    @ApiModelProperty("修改AR业务单商品信息同时更新商品信息")
    private String updateARBillAndGoods;

    @ApiModelProperty("默认红冲原因")
    private String redInvoiceReason;
    @ApiModelProperty("cusomterNo")
    private String customerNo;
    @ApiModelProperty("顾客提交抬头时手机号必填")
    private String invoiceTitlePhoneRequired;
    @ApiModelProperty("顾客可申请的发票类型")
    private List<String> invoiceTitleApplyInvoiceType;
    @ApiModelProperty("扫码H5类型")
    private String followWechat;
    @ApiModelProperty("订单查询来源")
    private String orderSearchSource;
    @ApiModelProperty("订单查询条件")
    private String orderSearchCondition;
    @ApiModelProperty("开票等待提示语(开票申请)")
    private String salesBillApplyInvoiceHint;
    @ApiModelProperty("顾客扫码填写额外信息(扫码抬头)")
    private String invoiceTitleCustomFieldName;
    @ApiModelProperty("顾客扫码额外信息是否必填(扫码抬头)")
    private String invoiceTitleCustomFieldRequired;
    @ApiModelProperty("已开订单是否可重复开具")
    private String canRepeatInvoice;
    @ApiModelProperty("上传是否自动【开电票】")
    private List<String> uploadBillAutoMakeElectronic;
    @ApiModelProperty("自动开具开票点配置")
    private String autoMakeTerminal;
    @ApiModelProperty("固定商品明细")
    private String invoiceFixedGoodsNo;
    @ApiModelProperty("商品匹配规则")
    private String goodsMatch;
    @ApiModelProperty("多订单添加")
    private String bulkOrderQueryFlag;
    @ApiModelProperty("项目code")
    private String thirdPartyCode;
    @ApiModelProperty("驳回后是否允许重复提交")
    private List<String> rejectApplyRepeatFlag;
    @ApiModelProperty("单据手工标记")
    private Integer billManualTag;
    @ApiModelProperty("单据手工标记规则")
    private Integer billManualTagRule;
    @ApiModelProperty("自动开具失败是否重试") //终端校验失败
    private Boolean checkTerminalFailIssueRetry;
    @ApiModelProperty("可开商品类型")
    private Integer recommendGoodsType;
    @ApiModelProperty("国税发票来源")
    private String taxInvoiceSource;
    @ApiModelProperty("是否允许修改商品税率")
    private Integer modifyTaxRateFlag;
    @ApiModelProperty("全电销方抬头")
    private Integer qdSellerTitle;
    @ApiModelProperty("全电开票是否强制反算税额")
    private Boolean qdForceBackCalculateTaxAmount;
    @ApiModelProperty("开票时手机/邮箱是否弹窗填写")
    private Boolean mobileEmailFillingMethod;
    @ApiModelProperty("发票红冲后是否允许消费者重开")
    private Boolean allowReissue = false;
    @ApiModelProperty("购方抬头库联想类型")
    private Integer purchaserTitleMatchType;
    @ApiModelProperty("手工开票页面抬头库来源")
    private String manualInvoiceTitleSource;
    @ApiModelProperty("专电红冲是否释放预制发票/业务单")
    private List<Integer> speElecInvoiceRedFlushReleaseFlag;
    @ApiModelProperty("数电发票备注展示银行信息")
    private List<String> sellerAndPurchaserControl;
    @ApiModelProperty("开具数电发票时是否支持新增开票人")
    private Boolean allowAddIssuer = false;
    @ApiModelProperty("数电自动开票是否需要负载均衡")
    private Boolean isAutoSelectIssuerFlag = false;
    @ApiModelProperty("是否校验相同门店")
    private String validSameStore;
    @ApiModelProperty("接口红冲的红票国税发票来源")
    private String taxInvoiceSourceForInterfaceRedFlush;
    @ApiModelProperty("展示组织类型")
    private Integer orgTypeView;
    @ApiModelProperty("数电票是否展示收款人、复核人")
    private Boolean checkEIvoiceDisplayOthers;

    @ApiModelProperty("红字确认单自动确认")
    private Boolean redBillAutoConfirmFlag;
    /**
     * 这里是选择是否在匹配红字确认单的时候读取红字匹配规则,默认不读取
     */
    @ApiModelProperty("红字业务单关联红字确认单是否读取规则")
    private Boolean redBillMatchRedConfirmMatchConfig;

    @ApiModelProperty("AR单小规模纳税人专票自动转普票")
    private Boolean smallScaleTaxpayerChangeToCommonInvoice;

    @ApiModelProperty("单据上传允许税额容差的国税发票来源")
    private List<String> uploadCheckByQd;

    @ApiModelProperty("单据开票允许税额容差的国税发票来源")
    private List<String> enableAdvancedValidation;
    @ApiModelProperty("数电票是否显示收款人复核人")
    private List<String> qdCashierAndInvoicerViewConfig;
    @ApiModelProperty("是否自动生成发票商品")
    private Boolean autoGenerateInvoiceGoods;
    @ApiModelProperty("合并后含税金额为0的业务单明细自动置为不开票")
    private Boolean modelACombineSetZeroToNotIssue;
    @ApiModelProperty("是否根据税编自动补充机动车标识")
    private Boolean jdcSpecialTypeFlag;
}
